@@ -1,14 +1,17 @@
 """``runway taxi`` command."""
 # docs: file://./../../../docs/source/commands.rst
 import logging
-from typing import Any  # pylint: disable=W
+from typing import TYPE_CHECKING, Any, cast
 
 import click
 
 from .. import options
 from ._plan import plan
 
-LOGGER = logging.getLogger(__name__.replace("._", "."))
+if TYPE_CHECKING:
+    from ..._logging import RunwayLogger
+
+LOGGER = cast("RunwayLogger", logging.getLogger(__name__.replace("._", ".")))
 
 
 @click.command("taxi", short_help="alias of plan")
@@ -19,8 +22,11 @@ LOGGER = logging.getLogger(__name__.replace("._", "."))
 @options.tags
 @options.verbose
 @click.pass_context
-def taxi(ctx, **kwargs):
-    # type: (click.Context, Any) -> None
-    """Alias of "runway plan"."""
+def taxi(ctx: click.Context, **kwargs: Any) -> None:
+    """Alias of "runway plan".
+
+    For more information, refer to the output of "runway plan --help".
+
+    """
     LOGGER.verbose("forwarding to plan...")
     ctx.forward(plan, **kwargs)
