@@ -1,6 +1,6 @@
 """``runway tfenv`` command group."""
 # docs: file://./../../../../docs/source/commands.rst
-from typing import Any  # pylint: disable=W
+from typing import Any
 
 import click
 
@@ -17,8 +17,7 @@ COMMANDS = [install, run]
 @options.debug
 @options.no_color
 @options.verbose
-def tfenv(**_):
-    # type: (Any) -> None
+def tfenv(**_: Any) -> None:
     """Terraform version management and execution.
 
     Runway's built-in Terraform version management allows for long-term
