@@ -1,7 +1,21 @@
 """CFNgin diff action."""
+from __future__ import annotations
+
 import logging
 import sys
 from operator import attrgetter
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    Generic,
+    List,
+    Tuple,
+    TypeVar,
+    Union,
+    cast,
+)
 
 from botocore.exceptions import ClientError
 
@@ -10,18 +24,26 @@ from .. import exceptions
 from ..status import (
     COMPLETE,
     INTERRUPTED,
+    DoesNotExistInCloudFormation,
     NotSubmittedStatus,
     NotUpdatedStatus,
     SkippedStatus,
 )
-from ..status import StackDoesNotExist as StackDoesNotExistStatus
-from . import build
+from . import deploy
 from .base import build_walker
 
-LOGGER = logging.getLogger(__name__)
+if TYPE_CHECKING:
+    from ..._logging import RunwayLogger
+    from ..stack import Stack
+    from ..status import Status
+
+_NV = TypeVar("_NV")
+_OV = TypeVar("_OV")
+
+LOGGER = cast("RunwayLogger", logging.getLogger(__name__))
 
 
-class DictValue(object):
+class DictValue(Generic[_OV, _NV]):
     """Used to create a diff of two dictionaries."""
 
     ADDED = "ADDED"
@@ -31,25 +53,24 @@ class DictValue(object):
 
     formatter = "%s%s = %s"
 
-    def __init__(self, key, old_value, new_value):
+    def __init__(self, key: str, old_value: _OV, new_value: _NV) -> None:
         """Instantiate class."""
         self.key = key
         self.old_value = old_value
         self.new_value = new_value
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
         """Compare if self is equal to another object."""
         return self.__dict__ == other.__dict__
 
-    def changes(self):
+    def changes(self) -> List[str]:
         """Return changes to represent the diff between old and new value.
 
         Returns:
-            List[str]: Representation of the change (if any) between old and
-            new value.
+            Representation of the change (if any) between old and new value.
 
         """
-        output = []
+        output: List[str] = []
         if self.status() is self.UNMODIFIED:
             output = [self.formatter % (" ", self.key, self.old_value)]
         elif self.status() is self.ADDED:
@@ -61,7 +82,7 @@ class DictValue(object):
             output.append(self.formatter % ("+", self.key, self.new_value))
         return output
 
-    def status(self):
+    def status(self) -> str:
         """Status of changes between the old value and new value."""
         if self.old_value == self.new_value:
             return self.UNMODIFIED
@@ -72,16 +93,18 @@ class DictValue(object):
         return self.MODIFIED
 
 
-def diff_dictionaries(old_dict, new_dict):
+def diff_dictionaries(
+    old_dict: Dict[str, _OV], new_dict: Dict[str, _NV]
+) -> Tuple[int, List[DictValue[_OV, _NV]]]:
     """Calculate the diff two single dimension dictionaries.
 
     Args:
-        old_dict(Dict[Any, Any]): Old dictionary.
-        new_dict(Dict[Any, Any]): New dictionary.
+        old_dict: Old dictionary.
+        new_dict: New dictionary.
 
     Returns:
-        Tuple[int, List[:class:`DictValue`]]: Number of changed records and
-        the :class:`DictValue` object containing the changes.
+        Number of changed records and the :class:`DictValue` object containing
+        the changes.
 
     """
     old_set = set(old_dict)
@@ -92,7 +115,7 @@ def diff_dictionaries(old_dict, new_dict):
     common_set = old_set & new_set
 
     changes = 0
-    output = []
+    output: List[DictValue[Any, Any]] = []
     for key in added_set:
         changes += 1
         output.append(DictValue(key, None, new_dict[key]))
@@ -110,19 +133,18 @@ def diff_dictionaries(old_dict, new_dict):
     return changes, output
 
 
-def format_params_diff(parameter_diff):
+def format_params_diff(parameter_diff: List[DictValue[Any, Any]]) -> str:
     """Handle the formatting of differences in parameters.
 
     Args:
-        parameter_diff (List[:class:`DictValue`]): A list of
-            :class:`DictValue` detailing the differences between two dicts
-            returned by :func:`diff_dictionaries`.
+        parameter_diff: A list of :class:`DictValue` detailing the differences
+            between two dicts returned by :func:`diff_dictionaries`.
 
     Returns:
-        str: A formatted string that represents a parameter diff
+        A formatted string that represents a parameter diff
 
     """
-    params_output = "\n".join([line for v in parameter_diff for line in v.changes()])
+    params_output = "\n".join(line for v in parameter_diff for line in v.changes())
     return (
         """--- Old Parameters
 +++ New Parameters
@@ -132,17 +154,19 @@ def format_params_diff(parameter_diff):
     )
 
 
-def diff_parameters(old_params, new_params):
+def diff_parameters(
+    old_params: Dict[str, _OV], new_params: Dict[str, _NV]
+) -> List[DictValue[_OV, _NV]]:
     """Compare the old vs. new parameters and returns a "diff".
 
     If there are no changes, we return an empty list.
 
     Args:
-        old_params(Dict[Any, Any]): old paramters
-        new_params(Dict[Any, Any]): new parameters
+        old_params: old paramters
+        new_params: new parameters
 
     Returns:
-        List[:class:`DictValue`]: A list of differences.
+        A list of differences.
 
     """
     changes, diff = diff_dictionaries(old_params, new_params)
@@ -151,10 +175,10 @@ def diff_parameters(old_params, new_params):
     return diff
 
 
-class Action(build.Action):
+class Action(deploy.Action):
     """Responsible for diffing CloudFormation stacks in AWS and locally.
 
-    Generates the build plan based on stack dependencies (these dependencies
+    Generates the deploy plan based on stack dependencies (these dependencies
     are determined automatically based on references to output values from
     other stacks).
 
@@ -167,27 +191,27 @@ class Action(build.Action):
     NAME = "diff"
 
     @property
-    def _stack_action(self):
+    def _stack_action(self) -> Callable[..., Status]:
         """Run against a step."""
         return self._diff_stack
 
-    def _diff_stack(
-        self, stack, **_kwargs
-    ):  # pylint: disable=too-many-return-statements
+    def _diff_stack(  # pylint: disable=too-many-return-statements
+        self, stack: Stack, **_: Any
+    ) -> Status:
         """Handle diffing a stack in CloudFormation vs our config."""
         if self.cancel.wait(0):
             return INTERRUPTED
 
-        if not build.should_submit(stack):
+        if not deploy.should_submit(stack):
             return NotSubmittedStatus()
 
-        provider = self.build_provider(stack)
+        provider = self.build_provider()
 
-        if not build.should_update(stack):
+        if not deploy.should_update(stack):
             stack.set_outputs(provider.get_outputs(stack.fqn))
             return NotUpdatedStatus()
 
-        tags = build.build_stack_tags(stack)
+        tags = deploy.build_stack_tags(stack)
 
         try:
             stack.resolve(self.context, provider)
@@ -204,7 +228,7 @@ class Action(build.Action):
                 return SkippedStatus(
                     "persistent graph: stack does not exist, will be removed"
                 )
-            return StackDoesNotExistStatus()
+            return DoesNotExistInCloudFormation()
         except AttributeError as err:
             if (
                 self.context.persistent_graph
@@ -226,7 +250,16 @@ class Action(build.Action):
             raise
         return COMPLETE
 
-    def run(self, **kwargs):
+    def run(
+        self,
+        *,
+        concurrency: int = 0,
+        dump: Union[bool, str] = False,  # pylint: disable=unused-argument
+        force: bool = False,  # pylint: disable=unused-argument
+        outline: bool = False,  # pylint: disable=unused-argument
+        tail: bool = False,  # pylint: disable=unused-argument
+        **_kwargs: Any,
+    ) -> None:
         """Kicks off the diffing of the stacks in the stack_definitions."""
         plan = self._generate_plan(
             require_unlocked=False, include_persistent_graph=True
@@ -236,28 +269,41 @@ class Action(build.Action):
             LOGGER.info("diffing stacks: %s", ", ".join(plan.keys()))
         else:
             LOGGER.warning("no stacks detected (error in config?)")
-        walker = build_walker(kwargs.get("concurrency", 0))
+        walker = build_walker(concurrency)
         plan.execute(walker)
 
-    def pre_run(self, **kwargs):
+    def pre_run(
+        self,
+        *,
+        dump: Union[bool, str] = False,  # pylint: disable=unused-argument
+        outline: bool = False,  # pylint: disable=unused-argument
+        **__kwargs: Any,
+    ) -> None:
         """Any steps that need to be taken prior to running the action.
 
         Handle CFNgin bucket access denied & not existing.
 
         """
-        if self.bucket_name:
-            bucket = Bucket(self.context, self.bucket_name, self.bucket_region)
-            if bucket.forbidden:
-                LOGGER.error("access denied for CFNgin bucket: %s", bucket.name)
-                sys.exit(1)
-            if bucket.not_found:
-                LOGGER.warning(
-                    'cfngin_bucket "%s" does not exist and will be creating '
-                    "during the next deploy",
-                    bucket.name,
-                )
-                LOGGER.verbose("proceeding without a cfngin_bucket...")
-                self.bucket_name = None
+        if not self.bucket_name:
+            return
+        bucket = Bucket(self.context, self.bucket_name, self.bucket_region)
+        if bucket.forbidden:
+            LOGGER.error("access denied for CFNgin bucket: %s", bucket.name)
+            sys.exit(1)
+        if bucket.not_found:
+            LOGGER.warning(
+                'cfngin_bucket "%s" does not exist and will be creating '
+                "during the next deploy",
+                bucket.name,
+            )
+            LOGGER.verbose("proceeding without a cfngin_bucket...")
+            self.bucket_name = None
 
-    def post_run(self, **kwargs):
+    def post_run(
+        self,
+        *,
+        dump: Union[bool, str] = False,  # pylint: disable=unused-argument
+        outline: bool = False,  # pylint: disable=unused-argument
+        **__kwargs: Any,
+    ) -> None:
         """Do nothing."""
