@@ -1,58 +1,68 @@
 """CFNgin entrypoint."""
+from __future__ import annotations
+
 import logging
 import os
-import re
 import sys
+from pathlib import Path
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, cast
 
 from yaml.constructor import ConstructorError
 
-from runway._logging import PrefixAdaptor
-from runway.util import MutableMap, SafeHaven, cached_property
-
-from .actions import build, destroy, diff
-from .config import render_parse_load as load_config
-from .context import Context as CFNginContext
+from .._logging import PrefixAdaptor
+from ..compat import cached_property
+from ..config import CfnginConfig
+from ..context import CfnginContext
+from ..utils import MutableMap, SafeHaven
+from .actions import deploy, destroy, diff
 from .environment import parse_environment
 from .providers.aws.default import ProviderBuilder
 
+if TYPE_CHECKING:
+    from .._logging import RunwayLogger
+    from ..context import RunwayContext
+
 # explicitly name logger so its not redundant
-LOGGER = logging.getLogger("runway.cfngin")
+LOGGER = cast("RunwayLogger", logging.getLogger("runway.cfngin"))
 
 
-class CFNgin(object):
+class CFNgin:
     """Control CFNgin.
 
     Attributes:
-        EXCLUDE_REGEX (str): Regex used to exclude YAML files when searching
-            for config files.
-        EXCLUDE_LIST (str): Global list of YAML file names to exclude when
-            searching for config files.
-        concurrency (int): Max number of CFNgin stacks that can be deployed
-            concurrently. If the value is ``0``, will be constrained based on
-            the underlying graph.
-        interactive (bool): Wether or not to prompt the user before taking
-            action.
-        parameters (MutableMap): Combination of the parameters provided when
-            initalizing the class and any environment files that are found.
-        recreate_failed (bool): Destroy and re-create stacks that are stuck in
+        concurrency: Max number of CFNgin stacks that can be deployed concurrently.
+            If the value is ``0``, will be constrained based on the underlying graph.
+        interactive: Whether or not to prompt the user before taking action.
+        parameters: Combination of the parameters provided when initalizing the
+            class and any environment files that are found.
+        recreate_failed: Destroy and re-create stacks that are stuck in
             a failed state from an initial deployment when updating.
-        region (str): The AWS region where CFNgin is currently being executed.
-        sys_path (str): Working directory.
-        tail (bool): Wether or not to display all CloudFormation events in the
-            terminal.
+        region: The AWS region where CFNgin is currently being executed.
+        sys_path: Working directory.
+        tail: Whether or not to display all CloudFormation events in the terminal.
 
     """
 
-    EXCLUDE_REGEX = r"runway(\..*)?\.(yml|yaml)"
-    EXCLUDE_LIST = ["bitbucket-pipelines.yml", "buildspec.yml", "docker-compose.yml"]
+    concurrency: int
+    interactive: bool
+    parameters: MutableMap
+    recreate_failed: bool
+    region: str
+    sys_path: Path
+    tail: bool
 
-    def __init__(self, ctx, parameters=None, sys_path=None):
+    def __init__(
+        self,
+        ctx: RunwayContext,
+        parameters: Optional[Dict[str, Any]] = None,
+        sys_path: Path = Path.cwd(),
+    ) -> None:
         """Instantiate class.
 
         Args:
-            ctx (runway.context.Context): Runway context object.
-            parameters (Optional[Dict[str. Any]]): Parameters from Runway.
-            sys_path (Optional[str]): Working directory.
+            ctx: Runway context object.
+            parameters: Parameters from Runway.
+            sys_path: Working directory.
 
         """
         self.__ctx = ctx
@@ -61,8 +71,8 @@ class CFNgin(object):
         self.interactive = ctx.is_interactive
         self.parameters = MutableMap()
         self.recreate_failed = ctx.is_noninteractive
-        self.region = ctx.env_region
-        self.sys_path = sys_path or os.getcwd()
+        self.region = ctx.env.aws_region
+        self.sys_path = sys_path
         self.tail = bool(ctx.env.debug or ctx.env.verbose)
 
         self.parameters.update(self.env_file)
@@ -74,17 +84,12 @@ class CFNgin(object):
         self._inject_common_parameters()
 
     @cached_property
-    def env_file(self):
-        """Contents of a CFNgin environment file.
-
-        Returns:
-            MutableMap
-
-        """
-        result = {}
+    def env_file(self) -> MutableMap:
+        """Contents of a CFNgin environment file."""
+        result: Dict[str, Any] = {}
         supported_names = [
-            "{}.env".format(self.__ctx.env_name),
-            "{}-{}.env".format(self.__ctx.env_name, self.region),
+            "{}.env".format(self.__ctx.env.name),
+            "{}-{}.env".format(self.__ctx.env.name, self.region),
         ]
         for _, file_name in enumerate(supported_names):
             file_path = os.path.join(self.sys_path, file_name)
@@ -95,13 +100,13 @@ class CFNgin(object):
                     result.update(parse_environment(file_.read()))
         return MutableMap(**result)
 
-    def deploy(self, force=False, sys_path=None):
+    def deploy(self, force: bool = False, sys_path: Optional[Path] = None) -> None:
         """Run the CFNgin deploy action.
 
         Args:
-            force (bool): Explicitly enable the action even if an environment
+            force: Explicitly enable the action even if an environment
                 file is not found.
-            sys_path (Optional[str]): Explicitly define a path to work in.
+            sys_path: Explicitly define a path to work in.
                 If not provided, ``self.sys_path`` is used.
 
         """
@@ -109,20 +114,17 @@ class CFNgin(object):
             return
         if not sys_path:
             sys_path = self.sys_path
-        config_file_names = self.find_config_files(sys_path=sys_path)
+        config_file_paths = self.find_config_files(sys_path=sys_path)
 
         with SafeHaven(
-            environ=self.__ctx.env_vars, sys_modules_exclude=["awacs", "troposphere"]
+            environ=self.__ctx.env.vars, sys_modules_exclude=["awacs", "troposphere"]
         ):
-            for config_name in config_file_names:
-                logger = PrefixAdaptor(os.path.basename(config_name), LOGGER)
+            for config_path in config_file_paths:
+                logger = PrefixAdaptor(os.path.basename(config_path), LOGGER)
                 logger.notice("deploy (in progress)")
-                with SafeHaven(
-                    argv=["stacker", "build", config_name],
-                    sys_modules_exclude=["awacs", "troposphere"],
-                ):
-                    ctx = self.load(config_name)
-                    action = build.Action(
+                with SafeHaven(sys_modules_exclude=["awacs", "troposphere"]):
+                    ctx = self.load(config_path)
+                    action = deploy.Action(
                         context=ctx,
                         provider_builder=self._get_provider_builder(
                             ctx.config.service_role
@@ -131,13 +133,13 @@ class CFNgin(object):
                     action.execute(concurrency=self.concurrency, tail=self.tail)
                 logger.success("deploy (complete)")
 
-    def destroy(self, force=False, sys_path=None):
+    def destroy(self, force: bool = False, sys_path: Optional[Path] = None) -> None:
         """Run the CFNgin destroy action.
 
         Args:
-            force (bool): Explicitly enable the action even if an environment
+            force: Explicitly enable the action even if an environment
                 file is not found.
-            sys_path (Optional[str]): Explicitly define a path to work in.
+            sys_path: Explicitly define a path to work in.
                 If not provided, ``self.sys_path`` is used.
 
         """
@@ -145,16 +147,16 @@ class CFNgin(object):
             return
         if not sys_path:
             sys_path = self.sys_path
-        config_file_names = self.find_config_files(sys_path=sys_path)
+        config_file_paths = self.find_config_files(sys_path=sys_path)
         # destroy should run in reverse to handle dependencies
-        config_file_names.reverse()
+        config_file_paths.reverse()
 
-        with SafeHaven(environ=self.__ctx.env_vars):
-            for config_name in config_file_names:
-                logger = PrefixAdaptor(os.path.basename(config_name), LOGGER)
+        with SafeHaven(environ=self.__ctx.env.vars):
+            for config_path in config_file_paths:
+                logger = PrefixAdaptor(config_path.name, LOGGER)
                 logger.notice("destroy (in progress)")
-                with SafeHaven(argv=["stacker", "destroy", config_name]):
-                    ctx = self.load(config_name)
+                with SafeHaven():
+                    ctx = self.load(config_path)
                     action = destroy.Action(
                         context=ctx,
                         provider_builder=self._get_provider_builder(
@@ -166,19 +168,17 @@ class CFNgin(object):
                     )
                 logger.success("destroy (complete)")
 
-    def load(self, config_path):
+    def load(self, config_path: Path) -> CfnginContext:
         """Load a CFNgin config into a context object.
 
         Args:
-            config_path (str): Valid path to a CFNgin config file.
-
-        Returns:
-            :class:`runway.cfngin.context.Context`
+            config_path: Valid path to a CFNgin config file.
 
         """
-        LOGGER.debug("loading CFNgin config: %s", os.path.basename(config_path))
+        LOGGER.debug("loading CFNgin config: %s", config_path.name)
         try:
             config = self._get_config(config_path)
+            config.load()
             return self._get_context(config, config_path)
         except ConstructorError as err:
             if err.problem.startswith(
@@ -193,13 +193,13 @@ class CFNgin(object):
                 sys.exit(1)
             raise
 
-    def plan(self, force=False, sys_path=None):
+    def plan(self, force: bool = False, sys_path: Optional[Path] = None):
         """Run the CFNgin plan action.
 
         Args:
-            force (bool): Explicitly enable the action even if an environment
+            force: Explicitly enable the action even if an environment
                 file is not found.
-            sys_path (Optional[str]): Explicitly define a path to work in.
+            sys_path: Explicitly define a path to work in.
                 If not provided, ``self.sys_path`` is used.
 
         """
@@ -207,13 +207,13 @@ class CFNgin(object):
             return
         if not sys_path:
             sys_path = self.sys_path
-        config_file_names = self.find_config_files(sys_path=sys_path)
-        with SafeHaven(environ=self.__ctx.env_vars):
-            for config_name in config_file_names:
-                logger = PrefixAdaptor(os.path.basename(config_name), LOGGER)
+        config_file_paths = self.find_config_files(sys_path=sys_path)
+        with SafeHaven(environ=self.__ctx.env.vars):
+            for config_path in config_file_paths:
+                logger = PrefixAdaptor(config_path.name, LOGGER)
                 logger.notice("plan (in progress)")
-                with SafeHaven(argv=["stacker", "diff", config_name]):
-                    ctx = self.load(config_name)
+                with SafeHaven():
+                    ctx = self.load(config_path)
                     action = diff.Action(
                         context=ctx,
                         provider_builder=self._get_provider_builder(
@@ -223,66 +223,53 @@ class CFNgin(object):
                     action.execute()
                 logger.success("plan (complete)")
 
-    def should_skip(self, force=False):
+    def should_skip(self, force: bool = False) -> bool:
         """Determine if action should be taken or not.
 
         Args:
-            force (bool): If ``True``, will always return ``False`` meaning
+            force: If ``True``, will always return ``False`` meaning
                 the action should not be skipped.
 
-        Returns:
-            bool: Skip action or not.
-
         """
         if force or self.env_file:
             return False
         LOGGER.info("skipped; no parameters and environment file not found")
         return True
 
-    def _get_config(self, file_path, validate=True):
+    def _get_config(self, file_path: Path) -> CfnginConfig:
         """Initialize a CFNgin config object from a file.
 
         Args:
-            file_path (str): Path to the config file to load.
-            validate (bool): Validate the loaded config.
-
-        Returns:
-            :class:`runway.cfngin.config.Config`
+            file_path: Path to the config file to load.
+            validate: Validate the loaded config.
 
         """
-        with open(file_path, "r") as file_:
-            raw_config = file_.read()
-        return load_config(raw_config, self.parameters, validate)
+        return CfnginConfig.parse_file(file_path=file_path, parameters=self.parameters)
 
-    def _get_context(self, config, config_path):
+    def _get_context(self, config: CfnginConfig, config_path: Path) -> CfnginContext:
         """Initialize a CFNgin context object.
 
         Args:
-            config (:class:`runway.cfngin.config.Config): CFNgin config object.
-            config_path (str): Path to the config file that was provided.
-
-        Returns:
-            :class:`runway.cfngin.context.Context`
+            config: CFNgin config object.
+            config_path: Path to the config file that was provided.
 
         """
-        return CFNginContext(
-            boto3_credentials=self.__ctx.boto3_credentials,
-            config=config,
+        return CfnginContext(
             config_path=config_path,
-            environment=self.parameters,
+            config=config,
+            deploy_environment=self.__ctx.env.copy(),
             force_stacks=[],  # placeholder
-            region=self.region,
+            parameters=self.parameters,
             stack_names=[],  # placeholder
         )
 
-    def _get_provider_builder(self, service_role=None):
+    def _get_provider_builder(
+        self, service_role: Optional[str] = None
+    ) -> ProviderBuilder:
         """Initialize provider builder.
 
         Args:
-            service_role (Optional[str]): CloudFormation service role.
-
-        Returns:
-            ProviderBuilder
+            service_role: CloudFormation service role.
 
         """
         if self.interactive:
@@ -296,7 +283,7 @@ class CFNgin(object):
             service_role=service_role,
         )
 
-    def _inject_common_parameters(self):
+    def _inject_common_parameters(self) -> None:
         """Add common parameters if they don't already exist.
 
         Adding these commonly used parameters will remove the need to add
@@ -316,43 +303,23 @@ class CFNgin(object):
 
         """
         if not self.parameters.get("environment"):
-            self.parameters["environment"] = self.__ctx.env_name
+            self.parameters["environment"] = self.__ctx.env.name
         if not self.parameters.get("region"):
             self.parameters["region"] = self.region
 
     @classmethod
-    def find_config_files(cls, exclude=None, sys_path=None):
+    def find_config_files(
+        cls, exclude: Optional[List[str]] = None, sys_path: Optional[Path] = None
+    ) -> List[Path]:
         """Find CFNgin config files.
 
         Args:
-            exclude (Optional[List[str]]): List of file names to exclude. This
-                list is appended to the global exclude list.
-            sys_path (Optional[str]): Explicitly define a path to search for
-                config files.
+            exclude: List of file names to exclude. This list is appended to
+                the global exclude list.
+            sys_path: Explicitly define a path to search for config files.
 
         Returns:
-            List[str]: Path to config files that were found.
+            Paths to config files that were found.
 
         """
-        if not sys_path:
-            sys_path = os.getcwd()
-        elif os.path.isfile(sys_path):
-            return [sys_path]
-
-        exclude = exclude or []
-        result = []
-        exclude.extend(cls.EXCLUDE_LIST)
-        for root, _dirs, files in os.walk(sys_path):
-            for name in files:
-                if re.match(cls.EXCLUDE_REGEX, name) or (
-                    name in exclude or name.startswith(".")
-                ):
-                    # Hidden files (e.g. .gitlab-ci.yml), Runway configs,
-                    # and docker-compose files definitely aren't stacker
-                    # config files
-                    continue
-                if os.path.splitext(name)[-1] in [".yaml", ".yml"]:
-                    result.append(os.path.join(root, name))
-            break  # only need top level files
-        result.sort()
-        return result
+        return CfnginConfig.find_config_file(sys_path, exclude=exclude)
