@@ -1,12 +1,16 @@
 """AMI lookup."""
-# pylint: disable=unused-argument,arguments-differ
+# pyright: reportIncompatibleMethodOverride=none
+from __future__ import annotations
+
 import operator
 import re
+from typing import TYPE_CHECKING, Any, Dict
 
-from runway.lookups.handlers.base import LookupHandler
+from ....lookups.handlers.base import LookupHandler
+from ...utils import read_value_from_path
 
-from ...session_cache import get_session
-from ...util import read_value_from_path
+if TYPE_CHECKING:
+    from ....context import CfnginContext
 
 TYPE_NAME = "ami"
 
@@ -14,30 +18,29 @@ TYPE_NAME = "ami"
 class ImageNotFound(Exception):
     """Image not found."""
 
-    def __init__(self, search_string):
+    search_string: str
+
+    def __init__(self, search_string: str) -> None:
         """Instantiate class."""
         self.search_string = search_string
         message = ("Unable to find ec2 image with search string: {}").format(
             search_string
         )
-        super(ImageNotFound, self).__init__(message)
+        super().__init__(message)
 
 
 class AmiLookup(LookupHandler):
     """AMI lookup."""
 
     @classmethod
-    def handle(cls, value, context=None, provider=None, **kwargs):
+    def handle(  # pylint: disable=arguments-differ
+        cls, value: str, context: CfnginContext, *__args: Any, **__kwargs: Any
+    ) -> str:
         """Fetch the most recent AMI Id using a filter.
 
         Args:
-            value (str): Parameter(s) given to this lookup.
-            context (:class:`runway.cfngin.context.Context`): Context instance.
-            provider (:class:`runway.cfngin.providers.base.BaseProvider`):
-                Provider instance.
-
-        Returns:
-            str: Looked up value.
+            value: Parameter(s) given to this lookup.
+            context: Context instance.
 
         Example:
             .. code-block:
@@ -68,15 +71,14 @@ class AmiLookup(LookupHandler):
         """  # noqa
         value = read_value_from_path(value)
 
+        region = None
         if "@" in value:
             region, value = value.split("@", 1)
-        else:
-            region = provider.region
 
-        ec2 = get_session(region).client("ec2")
+        ec2 = context.get_session(region=region).client("ec2")
 
-        values = {}
-        describe_args = {}
+        values: Dict[str, Any] = {}
+        describe_args: Dict[str, Any] = {}
 
         # now find any other arguments that can be filters
         matches = re.findall(r"([0-9a-zA-z_-]+:[^\s$]+)", value)
@@ -97,9 +99,7 @@ class AmiLookup(LookupHandler):
             executable_users = values.pop("executable_users").split(",")
             describe_args["ExecutableUsers"] = executable_users
 
-        filters = []
-        for k, v in values.items():
-            filters.append({"Name": k, "Values": v.split(",")})
+        filters = [{"Name": k, "Values": v.split(",")} for k, v in values.items()]
         describe_args["Filters"] = filters
 
         result = ec2.describe_images(**describe_args)
