@@ -1,10 +1,10 @@
 """Environment variable lookup."""
-# pylint: disable=unused-argument,arguments-differ
+# pyright: reportIncompatibleMethodOverride=none
 import os
+from typing import Any
 
-from runway.lookups.handlers.base import LookupHandler
-
-from ...util import read_value_from_path
+from ....lookups.handlers.base import LookupHandler
+from ...utils import read_value_from_path
 
 TYPE_NAME = "envvar"
 
@@ -13,14 +13,11 @@ class EnvvarLookup(LookupHandler):
     """Environment variable lookup."""
 
     @classmethod
-    def handle(cls, value, context=None, provider=None, **kwargs):
+    def handle(cls, value: str, **_: Any) -> str:  # pylint: disable=arguments-differ
         """Retrieve an environment variable.
 
         Args:
-            value (str): Parameter(s) given to this lookup.
-            context (:class:`runway.cfngin.context.Context`): Context instance.
-            provider (:class:`runway.cfngin.providers.base.BaseProvider`):
-                Provider instance.
+            value: Parameter(s) given to this lookup.
 
         Example:
             ::
@@ -46,5 +43,5 @@ class EnvvarLookup(LookupHandler):
 
         try:
             return os.environ[value]
-        except KeyError:
-            raise ValueError('EnvVar "{}" does not exist'.format(value))
+        except KeyError as exc:
+            raise ValueError('EnvVar "{}" does not exist'.format(value)) from exc
