@@ -1,17 +1,20 @@
 """AWS account."""
-from typing import TYPE_CHECKING, List  # pylint: disable=W
+from __future__ import annotations
 
-from ....util import cached_property
+from typing import TYPE_CHECKING, List, Union
+
+from ....compat import cached_property
 
 if TYPE_CHECKING:
-    from ....context import Context  # pylint: disable=W
+    import boto3
+
+    from ....context import CfnginContext, RunwayContext
 
 
-class AccountDetails(object):
+class AccountDetails:
     """AWS account details."""
 
-    def __init__(self, context):
-        # type: (Context) -> None
+    def __init__(self, context: Union[CfnginContext, RunwayContext]) -> None:
         """Instantiate class.
 
         Args:
@@ -21,18 +24,12 @@ class AccountDetails(object):
         self.__ctx = context
 
     @cached_property
-    def aliases(self):
-        # type: () -> List[str]
-        """Get the aliases of the AWS account.
-
-        Returns:
-            List[str]: Account aliases.
-
-        """
+    def aliases(self) -> List[str]:
+        """Get the aliases of the AWS account."""
         # Super overkill here using pagination when an account can only
         # have a single alias, but at least this implementation should be
         # future-proof.
-        aliases = []
+        aliases: List[str] = []
         paginator = self.__session.client("iam").get_paginator("list_account_aliases")
         response_iterator = paginator.paginate()
         for page in response_iterator:
@@ -40,18 +37,12 @@ class AccountDetails(object):
         return aliases
 
     @cached_property
-    def id(self):
-        # type: () -> str
-        """Get the ID of the AWS account.
-
-        Returns:
-            str: AWS account ID.
-
-        """
+    def id(self) -> str:
+        """Get the ID of the AWS account."""
         return self.__session.client("sts").get_caller_identity()["Account"]
 
     @cached_property
-    def __session(self):
+    def __session(self) -> boto3.Session:
         """Get a cached boto3 session.
 
         Session creation was moved out of class init to improve performance
