@@ -140,7 +140,7 @@ class BucketLister:
             kwargs.update(extra_args)
 
         paginator = self._client.get_paginator("list_objects_v2")
-        pages = paginator.paginate(**kwargs)
+        pages = paginator.paginate(**kwargs)  # type: ignore
         for page in pages:
             contents = page.get("Contents", [])
             for content in contents:
