@@ -1,5 +1,5 @@
 """Serverless module."""
-from __future__ import print_function
+from __future__ import annotations
 
 import argparse
 import logging
@@ -10,22 +10,33 @@ import subprocess
 import sys
 import tempfile
 import uuid
+from typing import IO, TYPE_CHECKING, Any, Callable, Dict, List, Optional, Union, cast
 
 import yaml
 
-from runway.hooks.staticsite.util import get_hash_of_files
-
 from .._logging import PrefixAdaptor
-from ..s3_util import does_s3_object_exist, download, ensure_bucket_exists, upload
-from ..util import YamlDumper, cached_property, merge_dicts
-from . import ModuleOptions, RunwayModuleNpm, generate_node_command, run_module_command
+from ..cfngin.hooks.staticsite.utils import get_hash_of_files
+from ..compat import cached_property
+from ..config.models.runway.options.serverless import (
+    RunwayServerlessModuleOptionsDataModel,
+)
+from ..s3_utils import does_s3_object_exist, download, ensure_bucket_exists, upload
+from ..utils import YamlDumper, merge_dicts
+from .base import ModuleOptions, RunwayModuleNpm
+from .utils import generate_node_command, run_module_command
 
-LOGGER = logging.getLogger(__name__)
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from .._logging import RunwayLogger
+    from ..context import RunwayContext
+
+LOGGER = cast("RunwayLogger", logging.getLogger(__name__))
 
 
-def gen_sls_config_files(stage, region):
+def gen_sls_config_files(stage: str, region: str) -> List[str]:
     """Generate possible SLS config files names."""
-    names = []
+    names: List[str] = []
     for ext in ["yml", "json"]:
         # Give preference to explicit stage-region files
         names.append(os.path.join("env", "%s-%s.%s" % (stage, region, ext)))
@@ -36,7 +47,9 @@ def gen_sls_config_files(stage, region):
     return names
 
 
-def run_sls_print(sls_opts, env_vars, path):
+def run_sls_print(
+    sls_opts: List[str], env_vars: Dict[str, str], path: Path
+) -> Dict[str, Any]:
     """Run sls print command."""
     sls_info_opts = list(sls_opts)
     sls_info_opts[0] = "print"
@@ -44,41 +57,48 @@ def run_sls_print(sls_opts, env_vars, path):
     sls_info_cmd = generate_node_command(
         command="sls", command_opts=sls_info_opts, path=path
     )
-    return yaml.safe_load(subprocess.check_output(sls_info_cmd, env=env_vars))
+    return yaml.safe_load(
+        subprocess.check_output(
+            sls_info_cmd, env={"SLS_DEPRECATION_DISABLE": "*", **env_vars}
+        )
+    )
 
 
-def get_src_hash(sls_config, path):
+def get_src_hash(sls_config: Dict[str, Any], path: Path) -> Dict[str, str]:
     """Get hash(es) of serverless source."""
     funcs = sls_config["functions"]
 
-    if sls_config.get("package", {}).get("individually"):
-        hashes = {
-            key: get_hash_of_files(
-                os.path.join(path, os.path.dirname(funcs[key].get("handler")))
-            )
+    if sls_config.get("package", {"": ""}).get("individually"):
+        return {
+            key: get_hash_of_files(path / os.path.dirname(funcs[key].get("handler")))
             for key in funcs.keys()
         }
-    else:
-        directories = []
-        for (key, value) in funcs.items():
-            func_path = {"path": os.path.dirname(value.get("handler"))}
-            if func_path not in directories:
-                directories.append(func_path)
-        hashes = {sls_config["service"]: get_hash_of_files(path, directories)}
-
-    return hashes
+    directories: List[Dict[str, Union[List[str], str]]] = []
+    for _key, value in funcs.items():
+        func_path = {"path": os.path.dirname(value.get("handler"))}
+        if func_path not in directories:
+            directories.append(func_path)
+    if isinstance(sls_config["service"], dict):
+        # handle sls<3.0.0 potential service property object notation
+        return {sls_config["service"]["name"]: get_hash_of_files(path, directories)}
+    return {sls_config["service"]: get_hash_of_files(path, directories)}
 
 
-def deploy_package(sls_opts, bucketname, context, path, logger=LOGGER):
+def deploy_package(
+    sls_opts: List[str],
+    bucketname: str,
+    context: RunwayContext,
+    path: Path,
+    logger: Union[logging.Logger, logging.LoggerAdapter] = LOGGER,
+) -> None:
     """Run sls package command.
 
     Args:
-        sls_opts (List[str]): List of options for Serverless CLI.
-        bucketname (str): S3 Bucket name.
-        context (Context): Runway context object.
-        path (str): Module path.
-        logger(Optional[logging.Logger]): A more granular
-            logger for log messages.
+        sls_opts: List of options for Serverless CLI.
+        bucketname: S3 Bucket name.
+        context: Runway context object.
+        path: Module path.
+        logger: A more granular logger for log messages.
 
     """
     package_dir = tempfile.mkdtemp()
@@ -94,11 +114,11 @@ def deploy_package(sls_opts, bucketname, context, path, logger=LOGGER):
         command="sls", command_opts=sls_opts, path=path
     )
 
-    logger.info("package %s (in progress)", os.path.basename(path))
+    logger.info("package %s (in progress)", path.name)
     run_module_command(
         cmd_list=sls_package_cmd, env_vars=context.env.vars, logger=logger
     )
-    logger.info("package %s (complete)", os.path.basename(path))
+    logger.info("package %s (complete)", path.name)
 
     for key in hashes.keys():
         hash_zip = hashes[key] + ".zip"
@@ -132,49 +152,60 @@ def deploy_package(sls_opts, bucketname, context, path, logger=LOGGER):
 class Serverless(RunwayModuleNpm):
     """Serverless Runway Module."""
 
-    def __init__(self, context, path, options=None):
+    options: ServerlessOptions
+
+    def __init__(
+        self,
+        context: RunwayContext,
+        *,
+        explicitly_enabled: Optional[bool] = False,
+        logger: RunwayLogger = LOGGER,
+        module_root: Path,
+        name: Optional[str] = None,
+        options: Optional[Union[Dict[str, Any], ModuleOptions]] = None,
+        parameters: Optional[Dict[str, Any]] = None,
+        **_: Any,
+    ) -> None:
         """Instantiate class.
 
         Args:
-            context (Context): Runway context object.
-            path (str): Path to the module.
-            options (Dict[str, Dict[str, Any]]): Everything in the module
-                definition merged with applicable values from the deployment
-                definition.
+            context: Runway context object for the current session.
+            explicitly_enabled: Whether or not the module is explicitly enabled.
+                This is can be set in the event that the current environment being
+                deployed to matches the defined environments of the module/deployment.
+            logger: Used to write logs.
+            module_root: Root path of the module.
+            name: Name of the module.
+            options: Options passed to the module class from the config as ``options``
+                or ``module_options`` if coming from the deployment level.
+            parameters: Values to pass to the underlying infrastructure as code
+                tool that will alter the resulting infrastructure being deployed.
+                Used to templatize IaC.
 
         """
-        options = options or {}
-        super(Serverless, self).__init__(context, path, options.copy())
-        self.logger = PrefixAdaptor(self.name, LOGGER)
-        try:
-            self.options = ServerlessOptions.parse(**options.get("options", {}))
-        except ValueError:
-            self.logger.exception("error encountered while parsing options")
-            sys.exit(1)
-        self.region = self.context.env.aws_region
-        self.stage = self.context.env.name
+        super().__init__(
+            context,
+            explicitly_enabled=explicitly_enabled,
+            logger=logger,
+            module_root=module_root,
+            name=name,
+            options=ServerlessOptions.parse_obj(options or {}),
+            parameters=parameters,
+        )
+        self.logger = PrefixAdaptor(self.name, logger)
+        self.stage = self.ctx.env.name
 
     @property
-    def cli_args(self):
-        """Generate CLI args from self used in all Serverless commands.
-
-        Returns:
-            List[str]
-
-        """
+    def cli_args(self) -> List[str]:
+        """Generate CLI args from self used in all Serverless commands."""
         result = ["--region", self.region, "--stage", self.stage]
-        if "DEBUG" in self.context.env.vars:
+        if "DEBUG" in self.ctx.env.vars:
             result.append("--verbose")
         return result
 
     @cached_property
-    def env_file(self):
-        """Find the environment file for the module.
-
-        Returns:
-            Path: Path object for the environment file that was found.
-
-        """
+    def env_file(self) -> Optional[Path]:
+        """Find the environment file for the module."""
         for name in gen_sls_config_files(self.stage, self.region):
             test_path = self.path / name
             if test_path.is_file():
@@ -182,15 +213,10 @@ class Serverless(RunwayModuleNpm):
         return None
 
     @property
-    def skip(self):
-        """Determine if the module should be skipped.
-
-        Returns:
-            bool: To skip, or not to skip, that is the question.
-
-        """
+    def skip(self) -> bool:
+        """Determine if the module should be skipped."""
         if not self.package_json_missing():
-            if self.parameters or self.environments or self.env_file:
+            if self.parameters or self.explicitly_enabled or self.env_file:
                 return False
             self.logger.info(
                 "skipped; config file for this stage/region not found"
@@ -204,12 +230,11 @@ class Serverless(RunwayModuleNpm):
             )
         return True
 
-    def extend_serverless_yml(self, func):
+    def extend_serverless_yml(self, func: Callable[..., None]) -> None:
         """Extend the Serverless config file with additional YAML from options.
 
         Args:
-            func (Callable): Callable to use after handling the Serverless
-                config file.
+            func: Callable to use after handling the Serverless config file.
 
         """
         self.npm_install()  # doing this here for a cleaner log
@@ -221,10 +246,7 @@ class Serverless(RunwayModuleNpm):
         tmp_file = self.path / "{}.tmp.serverless.yml".format(uuid.uuid4())
 
         try:
-            if self.context.is_python3:
-                tmp_file.write_text(yaml.safe_dump(final_yml))
-            else:  # TODO remove handling when dropping python 2 support
-                tmp_file.write_text(yaml.safe_dump(final_yml).decode("UTF-8"))
+            tmp_file.write_text(yaml.safe_dump(final_yml))
             self.logger.debug("created temporary Serverless config: %s", tmp_file)
             self.options.update_args("config", str(tmp_file.name))
             self.logger.debug(
@@ -243,35 +265,34 @@ class Serverless(RunwayModuleNpm):
                     exc_info=True,
                 )
 
-    def gen_cmd(self, command, args_list=None):
+    def gen_cmd(self, command: str, args_list: Optional[List[str]] = None) -> List[str]:
         """Generate and log a Serverless command.
 
         This does not execute the command, only prepares it for use.
 
         Args:
-            command (str): The Serverless command to be executed.
-            args_list (Optiona[List[str]]): Additional arguments to include
-                in the generated command.
+            command: The Serverless command to be executed.
+            args_list: Additional arguments to include in the generated command.
 
         Returns:
-            List[str]: The full command to be passed into a subprocess.
+            The full command to be passed into a subprocess.
 
         """
         args = [command] + self.cli_args + self.options.args
         args.extend(args_list or [])
-        if self.context.no_color and "--no-color" not in args:
+        if self.ctx.no_color and "--no-color" not in args:
             args.append("--no-color")
-        if command not in ["remove", "print"] and self.context.is_noninteractive:
+        if command not in ["remove", "print"] and self.ctx.is_noninteractive:
             args.append("--conceal")  # hide secrets from serverless output
         return generate_node_command(
             command="sls", command_opts=args, path=self.path, logger=self.logger
         )
 
-    def sls_deploy(self, skip_install=False):
+    def sls_deploy(self, skip_install: bool = False) -> None:
         """Execute ``sls deploy`` command.
 
         Args:
-            skip_install (bool): Skip ``npm install`` before running the
+            skip_install: Skip ``npm install`` before running the
                 Serverless command. (*default:* ``False``)
 
         """
@@ -282,35 +303,36 @@ class Serverless(RunwayModuleNpm):
             # TODO refactor deploy_package to be part of the class
             self.path.absolute()
             sls_opts = ["deploy"] + self.cli_args + self.options.args
-            if self.context.no_color and "--no-color" not in sls_opts:
+            if self.ctx.no_color and "--no-color" not in sls_opts:
                 sls_opts.append("--no-color")
             deploy_package(
                 sls_opts,
                 self.options.promotezip["bucketname"],
-                self.context,
-                str(self.path),
+                self.ctx,
+                self.path,
                 self.logger,
             )
             return
         self.logger.info("deploy (in progress)")
         run_module_command(
             cmd_list=self.gen_cmd("deploy"),
-            env_vars=self.context.env.vars,
+            env_vars=self.ctx.env.vars,
             logger=self.logger,
         )
         self.logger.info("deploy (complete)")
 
-    def sls_print(self, item_path=None, skip_install=False):
+    def sls_print(
+        self, item_path: Optional[str] = None, skip_install: bool = False
+    ) -> Dict[str, Any]:
         """Execute ``sls print`` command.
 
         Keyword Args:
-            item_path (Optional[str]): Period-separated path to print a
-                sub-value (eg: "provider.name").
-            skip_install (bool): Skip ``npm install`` before running the
-                Serverless command. (*default:* ``False``)
+            item_path: Period-separated path to print a sub-value (eg: "provider.name").
+            skip_install: Skip ``npm install`` before running the Serverless command.
+                (*default:* ``False``)
 
         Returns:
-            Dict[str, Any]: Resolved Serverless config file.
+            Resolved Serverless config file.
 
         Raises:
             SystemExit: If a runway-tmp.serverless.yml file already exists.
@@ -324,49 +346,51 @@ class Serverless(RunwayModuleNpm):
             args.extend(["--path", item_path])
         result = yaml.safe_load(
             subprocess.check_output(
-                self.gen_cmd("print", args_list=args), env=self.context.env.vars
+                self.gen_cmd("print", args_list=args),
+                # disable all deprecation messages to ensure the output is "clean"
+                env={"SLS_DEPRECATION_DISABLE": "*", **self.ctx.env.vars},
             )
         )
         # this could be expensive so only dump if needed
         if self.logger.getEffectiveLevel() == logging.DEBUG:
-            self.logger.debug(
+            self.logger.debug(  # cov: ignore
                 "resolved Serverless config:\n%s", yaml.dump(result, Dumper=YamlDumper)
             )
         return result
 
-    def sls_remove(self, skip_install=False):
+    def sls_remove(self, skip_install: bool = False) -> None:
         """Execute ``sls remove`` command.
 
         Args:
-            skip_install (bool): Skip ``npm install`` before running the
-                Serverless command. (*default:* ``False``)
+            skip_install: Skip ``npm install`` before running the Serverless command.
+                (*default:* ``False``)
 
         """
         if not skip_install:
             self.npm_install()
         stack_missing = False  # track output for acceptable error
         self.logger.info("destroy (in progress)")
-        proc = subprocess.Popen(
+        with subprocess.Popen(
             self.gen_cmd("remove"),
             bufsize=1,
-            env=self.context.env.vars,
+            env=self.ctx.env.vars,
             stdout=subprocess.PIPE,
             universal_newlines=True,
-        )
-        with proc.stdout:  # live output
-            for line in proc.stdout:
-                print(line, end="")
-                if re.search(r"Stack '.*' does not exist", line):
-                    stack_missing = True
+        ) as proc:
+            with cast(IO[str], proc.stdout):
+                for line in cast(IO[str], proc.stdout):
+                    print(line, end="")
+                    if re.search(r"Stack '.*' does not exist", line):
+                        stack_missing = True
         if proc.wait() != 0 and not stack_missing:
             sys.exit(proc.returncode)
         self.logger.info("destroy (complete)")
 
-    def plan(self):
+    def plan(self) -> None:
         """Entrypoint for Runway's plan action."""
         self.logger.info("plan not currently supported for Serverless")
 
-    def deploy(self):
+    def deploy(self) -> None:
         """Entrypoint for Runway's deploy action."""
         if self.skip:
             return
@@ -375,7 +399,7 @@ class Serverless(RunwayModuleNpm):
         else:
             self.sls_deploy()
 
-    def destroy(self):
+    def destroy(self) -> None:
         """Entrypoint for Runway's destroy action."""
         if self.skip:
             return
@@ -386,60 +410,55 @@ class Serverless(RunwayModuleNpm):
 
 
 class ServerlessOptions(ModuleOptions):
-    """Module options for Serverless."""
+    """Module options for Serverless Framework.
 
-    def __init__(self, args, extend_serverless_yml, promotezip, skip_npm_ci=False):
+    Attributes:
+        data: Options parsed into a data model.
+        extend_serverless_yml: If provided, the value of this option will be
+            recursively merged into the module's Serverless config file.
+        promotezip: If provided, promote Serverless Framework generated zip files
+            between environments from a build AWS account.
+        skip_npm_ci: Skip running ``npm ci`` in the module directory prior to
+            processing the module.
+
+    """
+
+    def __init__(self, data: RunwayServerlessModuleOptionsDataModel) -> None:
         """Instantiate class.
 
-        Keyword Args:
-            args (List[str]): Arguments to append to Serverless CLI
-                commands. These will always be placed after the default
-                arguments provided by Runway.
-            extend_serverless_yml (Dict[str, Any]): If provided,
-                a temporary Serverless config will be created will be created
-                from what exists in the module directory then the value of
-                this option will be merged into it. The temporary file will
-                be deleted at the end of execution.
-            promotezip (Dict[str, str]): If provided, promote
-                Serverless generated zip files between environments from a
-                *build* AWS account.
-            skip_npm_ci (bool): Skip the ``npm ci`` Runway executes at the
-                begining of each Serverless module run.
+        Args:
+            data: Options parsed into a data model.
 
         """
-        super(ServerlessOptions, self).__init__()
         self._arg_parser = self._create_arg_parser()
-        self.extend_serverless_yml = extend_serverless_yml
         cli_args, self._unknown_cli_args = self._arg_parser.parse_known_args(
-            list(args) if isinstance(args, list) else []  # python 2 compatible
+            data.args.copy()
         )
         self._cli_args = vars(cli_args)  # convert argparse.Namespace to dict
-        self.promotezip = promotezip
-        self.skip_npm_ci = skip_npm_ci
+
+        self.data = data
+        self.extend_serverless_yml = data.extend_serverless_yml
+        self.promotezip = data.promotezip
+        self.skip_npm_ci = data.skip_npm_ci
 
     @property
-    def args(self):
-        """Args to pass to the CLI.
-
-        Returns:
-            List[str]: List of arguments.
-
-        """
-        known_args = []
+    def args(self) -> List[str]:
+        """List of CLI arguments/options to pass to the Serverless Framework CLI."""
+        known_args: List[str] = []
         for key, val in self._cli_args.items():
             if isinstance(val, str):
                 known_args.extend(["--%s" % key, val])
         return known_args + self._unknown_cli_args
 
-    def update_args(self, key, value):
+    def update_args(self, key: str, value: str) -> None:
         """Update a known CLI argument.
 
         Args:
-            key (str): Dict key to be updated.
-            value (str): New value
+            key: Dict key to be updated.
+            value: New value
 
         Raises:
-            KeyError: The key provided for update is now a known arg.
+            KeyError: The key provided for update is not a known arg.
 
         """
         if key in self._cli_args:
@@ -448,7 +467,7 @@ class ServerlessOptions(ModuleOptions):
             raise KeyError(key)
 
     @staticmethod
-    def _create_arg_parser():
+    def _create_arg_parser() -> argparse.ArgumentParser:
         """Create argparse parser to parse args.
 
         Used to pull arguments out of self.args when logic could change
@@ -463,40 +482,11 @@ class ServerlessOptions(ModuleOptions):
         return parser
 
     @classmethod
-    def parse(cls, **kwargs):  # pylint: disable=arguments-differ
-        """Parse the options definition and return an options object.
+    def parse_obj(cls, obj: object) -> ServerlessOptions:
+        """Parse options definition and return an options object.
 
-        Keyword Args:
-            args (Optional[List[str]]): Arguments to append to Serverless CLI
-                commands. These will always be placed after the default
-                arguments provided by Runway.
-            extend_serverless_yml (Optional[Dict[str, Any]]): If provided,
-                a temporary Serverless config will be created will be created
-                from what exists in the module directory then the value of
-                this option will be merged into it. The temporary file will
-                be deleted at the end of execution.
-            promotezip (Optional[Dict[str, str]]): If provided, promote
-                Serverless generated zip files between environments from a
-                *build* AWS account.
-            skip_npm_ci (bool): Skip the ``npm ci`` Runway executes at the
-                begining of each Serverless module run.
-
-        Returns:
-            ServerlessOptions
-
-        Raises:
-            ValueError: promotezip was provided but missing bucketname.
+        Args:
+            obj: Object to parse.
 
         """
-        promotezip = kwargs.get("promotezip", {})
-        if promotezip and not promotezip.get("bucketname"):
-            raise ValueError(
-                '"bucketname" must be provided when using '
-                '"options.promotezip": {}'.format(promotezip)
-            )
-        return cls(
-            args=kwargs.get("args", []),
-            extend_serverless_yml=kwargs.get("extend_serverless_yml", {}),
-            promotezip=promotezip,
-            skip_npm_ci=kwargs.get("skip_npm_ci", False),
-        )
+        return cls(data=RunwayServerlessModuleOptionsDataModel.parse_obj(obj))
