@@ -1,19 +1,20 @@
 """cfn-list test runner."""
+from __future__ import annotations
+
 import logging
 import runpy
 import sys
-from typing import Any, Dict  # noqa pylint: disable=W
+from pathlib import Path
+from typing import TYPE_CHECKING, Any, Dict, Union
 
 import yaml
 
 from ..._logging import PrefixAdaptor
-from ...util import argv
+from ...utils import argv
 from .base import TestHandler
 
-if sys.version_info.major < 3:
-    from pathlib2 import Path  # pylint: disable=E
-else:
-    from pathlib import Path  # pylint: disable=E
+if TYPE_CHECKING:
+    from ...config.components.runway.base import ConfigProperty
 
 TYPE_NAME = "cfn-lint"
 LOGGER = logging.getLogger(__name__)
@@ -23,8 +24,7 @@ class CfnLintHandler(TestHandler):
     """Lints CFN."""
 
     @classmethod
-    def handle(cls, name, args):
-        # type: (str, Dict[str, Any]) -> None
+    def handle(cls, name: str, args: Union[ConfigProperty, Dict[str, Any]]) -> None:
         """Perform the actual test.
 
         Relies on .cfnlintrc file to be located beside the Runway config file.
